<?php

// autoload_psr4.php @generated by Composer

$vendorDir = dirname(__DIR__);
$baseDir = dirname(dirname($vendorDir));

return array(
    'Tawk\\Tests\\' => array($vendorDir . '/tawk/url-utils/tests'),
    'Tawk\\' => array($vendorDir . '/tawk/url-utils/lib'),
);
