<?php

// autoload_static.php @generated by Composer

namespace Composer\Autoload;

class ComposerStaticInitcdc366926c7feaedafc83315708262e0
{
    public static $prefixLengthsPsr4 = array (
        'T' =>
        array (
            'Tawk\\Tests\\' => 11,
            'Tawk\\' => 5,
        ),
    );

    public static $prefixDirsPsr4 = array (
        'Tawk\\Tests\\' =>
        array (
            0 => __DIR__ . '/..' . '/tawk/url-utils/tests',
        ),
        'Tawk\\' =>
        array (
            0 => __DIR__ . '/..' . '/tawk/url-utils/lib',
        ),
    );

    public static $classMap = array (
        'Composer\\InstalledVersions' => __DIR__ . '/..' . '/composer/InstalledVersions.php',
    );

    public static function getInitializer(ClassLoader $loader)
    {
        return \Closure::bind(function () use ($loader) {
            $loader->prefixLengthsPsr4 = ComposerStaticInitcdc366926c7feaedafc83315708262e0::$prefixLengthsPsr4;
            $loader->prefixDirsPsr4 = ComposerStaticInitcdc366926c7feaedafc83315708262e0::$prefixDirsPsr4;
            $loader->classMap = ComposerStaticInitcdc366926c7feaedafc83315708262e0::$classMap;

        }, null, ClassLoader::class);
    }
}
