<?php return array(
    'root' => array(
        'name' => 'tawk/tawk-wordpress',
        'pretty_version' => '0.9.3',
        'version' => '0.9.3.0',
        'reference' => null,
        'type' => 'project',
        'install_path' => __DIR__ . '/../../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        'tawk/tawk-wordpress' => array(
            'pretty_version' => '0.9.3',
            'version' => '0.9.3.0',
            'reference' => null,
            'type' => 'project',
            'install_path' => __DIR__ . '/../../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'tawk/url-utils' => array(
            'pretty_version' => '2.0.1',
            'version' => '2.0.1.0',
            'reference' => '73c166333707d893b0160fa9b5eae7aa8fbfa03c',
            'type' => 'library',
            'install_path' => __DIR__ . '/../tawk/url-utils',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
